Functions
===============================

1. Sample
*********

.. autoclass:: llg.sample.Sample
    :members:
    :show-inheritance:

.. autoclass:: llg.predefined_structures.GenericSc
    :members:
    :show-inheritance:

.. autoclass:: llg.predefined_structures.GenericBcc
    :members:
    :show-inheritance:

.. autoclass:: llg.predefined_structures.GenericFcc
    :members:
    :show-inheritance:

2. Site
*********

.. autoclass:: llg.site.Site
    :members:
    :show-inheritance:

3. Geometry
***********

.. autoclass:: llg.geometry.Geometry
    :members:
    :show-inheritance:

4. System
*********

.. autoclass:: llg.system.System
    :members:
    :show-inheritance:

5. Simulation
*************

.. autoclass:: llg.simulation.Simulation
    :members:
    :show-inheritance:

.. autoclass:: llg.bucket.Bucket
    :members:
    :show-inheritance:

6. Store
*********

.. autoclass:: llg.store.StoreHDF
    :members:
    :show-inheritance:

7. Plot States
**************

.. autoclass:: llg.plot_states.PlotStates
    :members:
    :show-inheritance:
